IbmModel1

Struct IbmModel1 

pub struct IbmModel1 {
    pub t_fe: Array2<f64>,
    pub t_0e: Array1<f64>,
}
IBM Model 1.

Fields

t_fe: Array2<f64>

Translation probability from source word f to target word e. t_fe[(f, e)] = Pr(e|f) Shape: (|source_vocab|, |target_vocab|)

t_0e: Array1<f64>

Translation probability from null word to target word e. t_e0[e] = Pr(e|NULL) Shape: (|target_vocab|,)

Implementations

Source

impl IbmModel1

pub fn train(corpus: &Corpus, iteration: u32) -> Self

Trains IBM Model 1.